<?php

namespace Mavabc\Casestudy\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Mavabc\Casestudy\Http\Requests\CasestudiesCategoryRequest;
use Mavabc\Casestudy\Interfaces\CasestudiesCategoryRepositoryInterface;
use Mavabc\Casestudy\Models\CasestudiesCategory;

/**
 * Resource controller class for casestudies_category.
 */
class CasestudiesCategoryResourceController extends BaseController
{

    /**
     * Initialize casestudies_category resource controller.
     *
     * @param type CasestudiesCategoryRepositoryInterface $casestudies_category
     *
     * @return null
     */
    public function __construct(CasestudiesCategoryRepositoryInterface $casestudies_category)
    {
        parent::__construct();
        $this->repository = $casestudies_category;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Mavabc\Casestudy\Repositories\Criteria\CasestudiesCategoryResourceCriteria::class);
    }

    /**
     * Display a list of casestudies_category.
     *
     * @return Response
     */
    public function index(CasestudiesCategoryRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Mavabc\Casestudy\Repositories\Presenter\CasestudiesCategoryPresenter::class)
                ->$function();
        }

        $casestudies_categories = $this->repository->paginate();

        return $this->response->title(trans('casestudy::casestudies_category.names'))
            ->view('casestudy::casestudies_category.index', true)
            ->data(compact('casestudies_categories'))
            ->output();
    }

    /**
     * Display casestudies_category.
     *
     * @param Request $request
     * @param Model   $casestudies_category
     *
     * @return Response
     */
    public function show(CasestudiesCategoryRequest $request, CasestudiesCategory $casestudies_category)
    {

        if ($casestudies_category->exists) {
            $view = 'casestudy::casestudies_category.show';
        } else {
            $view = 'casestudy::casestudies_category.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('casestudy::casestudies_category.name'))
            ->data(compact('casestudies_category'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new casestudies_category.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(CasestudiesCategoryRequest $request)
    {

        $casestudies_category = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('casestudy::casestudies_category.name')) 
            ->view('casestudy::casestudies_category.create', true) 
            ->data(compact('casestudies_category'))
            ->output();
    }

    /**
     * Create new casestudies_category.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(CasestudiesCategoryRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $casestudies_category                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('casestudy::casestudies_category.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('casestudy/casestudies_category/' . $casestudies_category->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/casestudy/casestudies_category'))
                ->redirect();
        }

    }

    /**
     * Show casestudies_category for editing.
     *
     * @param Request $request
     * @param Model   $casestudies_category
     *
     * @return Response
     */
    public function edit(CasestudiesCategoryRequest $request, CasestudiesCategory $casestudies_category)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('casestudy::casestudies_category.name'))
            ->view('casestudy::casestudies_category.edit', true)
            ->data(compact('casestudies_category'))
            ->output();
    }

    /**
     * Update the casestudies_category.
     *
     * @param Request $request
     * @param Model   $casestudies_category
     *
     * @return Response
     */
    public function update(CasestudiesCategoryRequest $request, CasestudiesCategory $casestudies_category)
    {
        try {
            $attributes = $request->all();

            $casestudies_category->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('casestudy::casestudies_category.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('casestudy/casestudies_category/' . $casestudies_category->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('casestudy/casestudies_category/' . $casestudies_category->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the casestudies_category.
     *
     * @param Model   $casestudies_category
     *
     * @return Response
     */
    public function destroy(CasestudiesCategoryRequest $request, CasestudiesCategory $casestudies_category)
    {
        try {

            $casestudies_category->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('casestudy::casestudies_category.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('casestudy/casestudies_category/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('casestudy/casestudies_category/' . $casestudies_category->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple casestudies_category.
     *
     * @param Model   $casestudies_category
     *
     * @return Response
     */
    public function delete(CasestudiesCategoryRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('casestudy::casestudies_category.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('casestudy/casestudies_category'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/casestudy/casestudies_category'))
                ->redirect();
        }

    }

    /**
     * Restore deleted casestudies_categories.
     *
     * @param Model   $casestudies_category
     *
     * @return Response
     */
    public function restore(CasestudiesCategoryRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('casestudy::casestudies_category.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/casestudy/casestudies_category'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/casestudy/casestudies_category/'))
                ->redirect();
        }

    }

}
