<?php

namespace Mavabc\Casestudy\Policies;

use Litepie\User\Contracts\UserPolicy;
use Mavabc\Casestudy\Models\CasestudiesCategory;

class CasestudiesCategoryPolicy
{

    /**
     * Determine if the given user can view the casestudies_category.
     *
     * @param UserPolicy $user
     * @param CasestudiesCategory $casestudies_category
     *
     * @return bool
     */
    public function view(UserPolicy $user, CasestudiesCategory $casestudies_category)
    {
        if ($user->canDo('casestudy.casestudies_category.view') && $user->isAdmin()) {
            return true;
        }

        return $casestudies_category->user_id == user_id() && $casestudies_category->user_type == user_type();
    }

    /**
     * Determine if the given user can create a casestudies_category.
     *
     * @param UserPolicy $user
     * @param CasestudiesCategory $casestudies_category
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('casestudy.casestudies_category.create');
    }

    /**
     * Determine if the given user can update the given casestudies_category.
     *
     * @param UserPolicy $user
     * @param CasestudiesCategory $casestudies_category
     *
     * @return bool
     */
    public function update(UserPolicy $user, CasestudiesCategory $casestudies_category)
    {
        if ($user->canDo('casestudy.casestudies_category.edit') && $user->isAdmin()) {
            return true;
        }

        return $casestudies_category->user_id == user_id() && $casestudies_category->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given casestudies_category.
     *
     * @param UserPolicy $user
     * @param CasestudiesCategory $casestudies_category
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, CasestudiesCategory $casestudies_category)
    {
        return $casestudies_category->user_id == user_id() && $casestudies_category->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given casestudies_category.
     *
     * @param UserPolicy $user
     * @param CasestudiesCategory $casestudies_category
     *
     * @return bool
     */
    public function verify(UserPolicy $user, CasestudiesCategory $casestudies_category)
    {
        if ($user->canDo('casestudy.casestudies_category.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given casestudies_category.
     *
     * @param UserPolicy $user
     * @param CasestudiesCategory $casestudies_category
     *
     * @return bool
     */
    public function approve(UserPolicy $user, CasestudiesCategory $casestudies_category)
    {
        if ($user->canDo('casestudy.casestudies_category.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
