<?php

namespace Mavabc\Casestudy\Providers;

use Illuminate\Support\ServiceProvider;

class CasestudyServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'casestudy');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'casestudy');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('mavabc.casestudy', function ($app) {
            return $this->app->make('Mavabc\Casestudy\Casestudy');
        });

        // Bind Casestudy to repository
        $this->app->bind(
            'Mavabc\Casestudy\Interfaces\CasestudyRepositoryInterface',
            \Mavabc\Casestudy\Repositories\Eloquent\CasestudyRepository::class
        );        // Bind CasestudiesCategory to repository
        $this->app->bind(
            'Mavabc\Casestudy\Interfaces\CasestudiesCategoryRepositoryInterface',
            \Mavabc\Casestudy\Repositories\Eloquent\CasestudiesCategoryRepository::class
        );

        $this->app->register(\Mavabc\Casestudy\Providers\AuthServiceProvider::class);
                $this->app->register(\Mavabc\Casestudy\Providers\EventServiceProvider::class);
        
        $this->app->register(\Mavabc\Casestudy\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['mavabc.casestudy'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('mavabc/casestudy.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/casestudy')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/casestudy')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
